@@ -12,10 +12,15 @@ try:
 except Exception:
     __version__ = "unknown"
 
+import pint
 
-k_B = 8.617e-5  # eV/K
-Rg = 8.314
-avogadro_nb = 6.022e23
+ureg = pint.UnitRegistry()
+ureg.setup_matplotlib()
+pint.set_application_registry(ureg)
+
+k_B = 8.617e-5 * ureg.eV * ureg.particle**-1 * ureg.K**-1
+Rg = 8.314 * ureg.Pa * ureg.m**3 * ureg.mol**-1 * ureg.K**-1
+avogadro_nb = 6.022e23 * ureg.particle * ureg.mol**-1
 
 from pybtex.database import parse_file
 from pathlib import Path
@@ -35,10 +40,11 @@ from .properties_group import PropertiesGroup
 from . import conversion
 from . import fitting
 from . import plotting
+from .material import *
 
 database = PropertiesGroup()
 
-from .materials import *
+from . import property_database
 
 diffusivities = PropertiesGroup(
     prop for prop in database if isinstance(prop, Diffusivity)
